@@ -30,7 +30,11 @@ END { print SHOW_CURSOR }
 
 sub download_youtube {
     my ( $opt, $info ) = @_;
-    my $ua = LWP::UserAgent->new( agent => $opt->{useragent}, show_progress => 0 );
+    my $ua = LWP::UserAgent->new(
+        agent         => $opt->{useragent},
+        timeout       => $opt->{timeout},
+        show_progress => 0,
+    );
     my $nr = 1;
     for my $video_id ( sort { $info->{$a}{count} <=> $info->{$b}{count} } keys %$info ) {
         for my $fmt ( sort keys %{$info->{$video_id}{video_url}} ) {
@@ -39,8 +43,8 @@ sub download_youtube {
                 unlink $file_name_OS or die $! if -f $file_name_OS && $opt->{overwrite};
                 _download_video( $opt, $info, $ua, $video_id, $fmt, $nr );
                 if ( $opt->{upload_date_is_file_date} ) {
-                    if ( $info->{$video_id}{upload_date} =~ /^(\d\d\d\d)-(\d\d)-(\d\d)\z/ ) {
-                        my $time = timelocal( 0, 0, 0, $3, $2 - 1, $1 );
+                    if ( $info->{$video_id}{upload_datetime} =~ /^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)\z/ ) {
+                        my $time = timelocal( $6, $5, $4, $3, $2 - 1, $1 );
                         my $ref = File::Touch->new( time => $time );
                         my $count = $ref->touch( $file_name_OS );
                     }
