@@ -25,7 +25,7 @@ sub _youtube_print_info {
     my ( $opt, $info, $video_id ) = @_;
     my $message = "** GET download info: ";
     my $json = get_download_info_as_json( $opt, $video_id, $message );
-    json_to_hash( $json, $info ) if $json;
+    json_to_hash( $opt, $info, $json ) if $json;
 }
 
 
