@@ -8,7 +8,6 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( from_arguments_to_choices );
 
-use JSON                   qw( decode_json );
 use List::MoreUtils        qw( any none );
 use Term::ANSIScreen       qw( :cursor :screen );
 use Term::Choose           qw( choose );
@@ -16,9 +15,8 @@ use Term::ReadLine::Simple qw();
 use URI                    qw();
 use URI::Escape            qw( uri_unescape );
 
-use App::YTDL::Data         qw( wrapper_get get_download_info_as_json );
+use App::YTDL::Data         qw( get_yt_download_info_as_h_ref get_download_info_as_json );
 use App::YTDL::Data_Extract qw( add_entry_to_info_hash json_to_hash );
-use App::YTDL::Helper       qw( insert_sep );
 use App::YTDL::Config       qw( sort_order_list );
 
 
@@ -164,14 +162,12 @@ sub _id_to_tmp_info_hash {
     while ( $count_entries == $max_results ) {  # or <link rel='next'>
         $url->query_form( 'start-index' => $start_index, 'max-results' => $max_results, 'v' => $opt->{yt_api_v}, 'alt' => 'json' );
         $start_index += $max_results;
-        my $res = wrapper_get( $opt, $url->as_string );
-        if ( ! defined $res ) {
+        my $h_ref = get_yt_download_info_as_h_ref( $opt, $url->as_string );
+        if ( ! defined $h_ref ) {
             my $err_msg = $type . ': ' . $list_id . '   ' . ( $start_index - $max_results ) . '-' . $start_index;
             push @{$opt->{error_get_download_infos}}, $err_msg;
             next;
         }
-        my $json = $res->decoded_content;
-        my $h_ref = decode_json( $json ); #
         my $entries = $h_ref->{feed}{entry};
         $count_entries = @$entries;
         if ( ! $count_entries ) {
@@ -200,14 +196,12 @@ sub _more_url_to_tmp_info_hash {
     for my $video_id ( split /,/, $more_ids ) {
         my $url = URI->new( 'https://gdata.youtube.com/feeds/api/videos/' . $video_id );
         $url->query_form( 'v' => $opt->{yt_api_v}, 'alt' => 'json' );
-        my $res = wrapper_get( $opt, $url );
-        if ( ! defined $res ) {
+        my $h_ref = get_yt_download_info_as_h_ref( $opt, $url );
+        if ( ! defined $h_ref ) {
             my $err_msg = 'Video group: ' . $more_ids . ' - ' . $video_id . '   ' . $url;
             push @{$opt->{error_get_download_infos}}, $err_msg;
             next;
         }
-        my $json = $res->decoded_content;
-        my $h_ref = decode_json( $json );
         my $entry = $h_ref->{feed}{entry};
         add_entry_to_info_hash( $opt, $tmp, $entry );
     }
@@ -345,7 +339,8 @@ sub _choose_videos_and_add_to_info_hash {
                 next FILTER;
             }
             else {
-                last FILTER;
+                return;
+                #last FILTER;
             }
         }
     }
